@@ -3,5 +3,5 @@
 """Top-level package for adbasicapi."""
 
 __author__ = """Nicolas Cordier"""
-__email__ = 'nicolas.cordier@numeric-gmbh.ch'
-__version__ = '0.1.0'
+__email__ = "nicolas.cordier@numeric-gmbh.ch"
+__version__ = "0.3.0"
